<h4 align="center">
    <img alt="logo" src="https://raw.githubusercontent.com/imum-ai/promptlab/main/img/logo.png" style="">
</h4>

## Table of Contents
- [PromptLab](#promptlab)
- [Why PromptLab](#why-promptlab)
- [Documentation](#documentation)
- [Samples](#samples)

## PromptLab

PromptLab is a free, lightweight, open-source experimentation tool for Gen AI applications. 

## Why PromptLab

PromptLab streamlines prompt engineering, making it easy to set up experiments, evaluate prompts, and track them in production.

Key Benefits:

✅ Easy to adopt – No ML or Data Science expertise required.

✅ Self-contained – No need for additional cloud services for tracking or collaboration.

✅ Seamless integration – Works within your existing web, mobile, or backend project.

## Documentation

Check the [documentation](https://github.com/imum-ai/promptlab/blob/main/docs/README.md)

## Samples

- [Quickstart](https://github.com/imum-ai/promptlab/tree/main/samples/quickstart)